@@ -180,7 +180,7 @@ class Session:
             self.session.headers["content-type"] = "application/x-www-form-urlencoded"
             loginResp1 = self.session.post("https://ids.tongji.edu.cn:8443/nidp/app/login?sid=0&sid=0", data=dataToSend)
             urls = re.findall(r"window\.location\.href=\'(.*?)\'", loginResp1.text)
-            if len(urls) > 0:
+            if len(urls) > 0 and "tongjiaccount" not in urls[0]:
                 href = urls[0]
             else:
                 raise ValueError("登录失败，请检查学号，密码是否正确！")
@@ -312,4 +312,4 @@ class Session:
 
 
 if __name__ == "__main__":
-    print(Session("2152955", "831033"))
+    print(Session("2152955", "ZSYzsy20030810",manual=True))
